==> proximl-0.5.4.tar.gz: proximl-0.5.4/tests/integration/test_datasets_integration.py <==
import re
import sys
import asyncio
from pytest import mark, fixture

pytestmark = [mark.sdk, mark.integration, mark.datasets]


@mark.create
@mark.asyncio
class GetDatasetTests:
    @fixture(scope="class")
    async def dataset(self, proximl):
        dataset = await proximl.datasets.create(
            name="CLI Automated",
            source_type="aws",
            source_uri="s3://proximl-examples/data/cifar10",
        )
        dataset = await dataset.wait_for("ready", 300)
        yield dataset
        await dataset.remove()
        dataset = await dataset.wait_for("archived", 60)

    async def test_get_public_datasets(self, proximl):
        datasets = await proximl.datasets.list_public()
        assert len(datasets) > 0

    async def test_get_my_datasets(self, proximl, dataset):
        datasets = await proximl.datasets.list()
        assert len(datasets) > 0

    async def test_get_dataset(self, proximl, dataset):
        response = await proximl.datasets.get(dataset.id)
        assert response.id == dataset.id

    async def test_dataset_properties(self, dataset):
        assert isinstance(dataset.id, str)
        assert isinstance(dataset.status, str)
        assert isinstance(dataset.name, str)
        assert isinstance(dataset.size, int)

    async def test_dataset_str(self, dataset):
        string = str(dataset)
        regex = r"^{.*\"dataset_uuid\": \"" + dataset.id + r"\".*}$"
        assert isinstance(string, str)
        assert re.match(regex, string)

    async def test_dataset_repr(self, dataset):
        string = repr(dataset)
        regex = (
            r"^Dataset\( proximl , \*\*{.*'dataset_uuid': '"
            + dataset.id
            + r"'.*}\)$"
        )
        assert isinstance(string, str)
        assert re.match(regex, string)

    async def test_get_dataset_log_url(self, dataset, request):
        env = request.config.getoption("--env")
        regex = (
            r"https://trainml-jobs-"
            + env
            + r".s3.us-east-2.amazonaws.com/"
            + dataset.id
            + r"/logs/"
            + dataset.name.replace(" ", "_")
            + r".zip\?X-Amz"
        )
        response = await dataset.get_log_url()
        assert re.match(regex, response)

    async def test_get_dataset_details(self, dataset):
        response = await dataset.get_details()
        assert response.get("contents") == []
        assert response.get("count") == "8"
        assert response.get("name") == "/"
        assert response.get("size") == "177M" or response.get("size") == "176M"


@mark.create
@mark.asyncio
async def test_dataset_local(proximl, capsys):
    dataset = await proximl.datasets.create(
        name="CLI Automated Local",
        source_type="local",
        source_uri="~/cifar-10",
    )
    attach_task = asyncio.create_task(dataset.attach())
    connect_task = asyncio.create_task(dataset.connect())
    await asyncio.gather(attach_task, connect_task)
    await dataset.disconnect()
    await dataset.refresh()
    status = dataset.status
    size = dataset.size
    await dataset.remove()
    assert status == "ready"
    assert size >= 10000000
    captured = capsys.readouterr()
    sys.stdout.write(captured.out)
    sys.stderr.write(captured.err)
    assert "Starting data upload from local" in captured.out
    assert "data_batch_1.bin  30733788 bytes" in captured.out
    assert "Upload complete" in captured.out

==> proximl-0.5.15.tar.gz: proximl-0.5.15/tests/integration/test_datasets_integration.py <==
import re
import sys
import asyncio
from pytest import mark, fixture

pytestmark = [mark.sdk, mark.integration, mark.datasets]


@mark.create
@mark.asyncio
@mark.xdist_group("datasets")
class GetDatasetTests:
    @fixture(scope="class")
    async def dataset(self, proximl):
        dataset = await proximl.datasets.create(
            name="CLI Automated",
            source_type="wasabi",
            source_uri="s3://proximl-example/input/cifar-10/cifar-10-batches-bin",
            source_options=dict(endpoint_url="https://s3.wasabisys.com"),
        )
        dataset = await dataset.wait_for("ready", 300)
        yield dataset
        await dataset.remove()
        dataset = await dataset.wait_for("archived", 60)

    async def test_get_public_datasets(self, proximl):
        datasets = await proximl.datasets.list_public()
        assert len(datasets) > 0

    async def test_get_my_datasets(self, proximl, dataset):
        datasets = await proximl.datasets.list()
        assert len(datasets) > 0

    async def test_get_dataset(self, proximl, dataset):
        response = await proximl.datasets.get(dataset.id)
        assert response.id == dataset.id

    async def test_dataset_properties(self, dataset):
        assert isinstance(dataset.id, str)
        assert isinstance(dataset.status, str)
        assert isinstance(dataset.name, str)
        assert isinstance(dataset.size, int)

    async def test_dataset_str(self, dataset):
        string = str(dataset)
        regex = r"^{.*\"dataset_uuid\": \"" + dataset.id + r"\".*}$"
        assert isinstance(string, str)
        assert re.match(regex, string)

    async def test_dataset_repr(self, dataset):
        string = repr(dataset)
        regex = (
            r"^Dataset\( proximl , \*\*{.*'dataset_uuid': '" + dataset.id + r"'.*}\)$"
        )
        assert isinstance(string, str)
        assert re.match(regex, string)

    async def test_get_dataset_log_url(self, dataset, request):
        env = request.config.getoption("--env")
        regex = (
            r"https://trainml-jobs-"
            + env
            + r".s3.us-east-2.amazonaws.com/"
            + dataset.id
            + r"/logs/"
            + dataset.name.replace(" ", "_")
            + r".zip\?X-Amz"
        )
        response = await dataset.get_log_url()
        assert re.match(regex, response)

    async def test_get_dataset_details(self, dataset):
        response = await dataset.get_details()
        assert response.get("contents") == []
        assert response.get("count") == "8"
        assert response.get("name") == "/"
        assert response.get("size") == "177M" or response.get("size") == "176M"


@mark.create
@mark.asyncio
async def test_dataset_local(proximl, capsys):
    dataset = await proximl.datasets.create(
        name="CLI Automated Local",
        source_type="local",
        source_uri="~/cifar-10",
    )
    attach_task = asyncio.create_task(dataset.attach())
    connect_task = asyncio.create_task(dataset.connect())
    await asyncio.gather(attach_task, connect_task)
    await dataset.disconnect()
    await dataset.refresh()
    status = dataset.status
    size = dataset.size
    await dataset.remove()
    assert status == "ready"
    assert size >= 10000000
    captured = capsys.readouterr()
    sys.stdout.write(captured.out)
    sys.stderr.write(captured.err)
    assert "Starting data upload from local" in captured.out
    assert "data_batch_1.bin  30733788 bytes" in captured.out
    assert "Upload complete" in captured.out
